@@ -70,7 +70,7 @@ class Logic():
             update_peer = False
             # Act based on current state
             next = 'unchanged'
-            if peerdata.get('handshake-status', 'failed') != 'failed':
+            if peerdata.get('handshake-status', 'failed') not in ['none', 'failed']:
                 if peerdata.get('ping-address') is None:
                     peerdata['ping-address'] = peerdata['allowed-ips'][0].partition('/')[0]
                 if ping_interval > 0:
@@ -174,7 +174,7 @@ class Logic():
         needed_endpoint = None
         try:
             needed_endpoint = socket.getaddrinfo(config_endpoint, 0)[0][4][0] # get ip address
-        except socket.gaierror:
+        except socket.gaierror as e:
             # Something like "socket.gaierror: [Errno -3] Try again" can happen here
             logger.warning('Error resolving interface endpoint [{0}]: {1}'.format(config_endpoint, str(e)))            
         if (needed_endpoint is not None) and (needed_endpoint != endpoint):
